# django-smart-env

[![Test](https://github.com/unicef/django-smart-env/actions/workflows/test.yml/badge.svg)](https://github.com/unicef/django-smart-env/actions/workflows/test.yml)
[![Lint](https://github.com/unicef/django-smart-env/actions/workflows/lint.yml/badge.svg)](https://github.com/unicef/django-smart-env/actions/workflows/lint.yml)
[![Documentation](https://github.com/unicef/django-smart-env/actions/workflows/docs.yml/badge.svg)](https://github.com/unicef/django-smart-env/actions/workflows/docs.yml)
[![codecov](https://codecov.io/github/unicef/django-smart-env/branch/develop/graph/badge.svg?token=3ZmxTFfYra)](https://codecov.io/github/unicef/django-smart-env)
[![Pypi](https://badge.fury.io/py/django-smart-env.svg)](https://badge.fury.io/py/django-smart-env)



package django-smart-env is a small add-on to the [django-environ](https://django-environ.readthedocs.io/en/latest/), it provides some extra features

- extend configuration
- management command
- django check framework integration
